==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+46"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
O seu tema não suporta menus de navegação ou de widgets.
O seu tema não suporta menus de navegação ou de widgets
Texto a mostrar</translatorcomment>
        <translation>Navegação</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (Roda do Mouse)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rolagem (Trackpad, Mouse de Múltiplos Botões)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Roda do mouse / deslocamento de dois dedos:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Habilite o gesto de deslocamento</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inverso sentido roda do mouse para zoom</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Roda do mouse fator de zoom:</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limite o zoom e a rolagem para evitar excessos</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+47"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
O seu tema não suporta menus de navegação ou de widgets.
O seu tema não suporta menus de navegação ou de widgets
Texto a mostrar</translatorcomment>
        <translation>Navegação</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (Roda do Mouse)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rolagem (Trackpad, Mouse de Múltiplos Botões)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Roda do mouse / deslocamento de dois dedos:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Habilite o gesto de deslocamento</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inverso sentido roda do mouse para zoom</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Middle mouse button zoom factor:</source>
        <translation>Fator de zoom do botão do meio do mouse:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Roda do mouse fator de zoom:</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Panning threshold (px):</source>
        <translation>Limar de panning:</translation>
    </message>
    <message>
        <location line="-217"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limite o zoom e a rolagem para evitar excessos</translation>
    </message>
</context>
</TS>
